==> postcss-cssnext-2.11.0.tgz: package/README.md <==
# postcss-cssnext

[![Travis Build Status](https://img.shields.io/travis/MoOx/postcss-cssnext.svg?label=unix%20build)](https://travis-ci.org/cssnext/postcss-cssnext)
[![AppVeyor Build Status](https://img.shields.io/appveyor/ci/MoOx/postcss-cssnext.svg?label=windows%20build)](https://ci.appveyor.com/project/MoOx/postcss-cssnext)
[![Version](https://img.shields.io/npm/v/postcss-cssnext.svg)](https://github.com/MoOx/postcss-cssnext/blob/master/CHANGELOG.md)
[![Support on gitter chat](https://img.shields.io/badge/support-gitter%20chat-E40255.svg)](https://gitter.im/MoOx/postcss-cssnext)


> PostCSS plugin to use tomorrow’s CSS syntax, today.

PostCSS-cssnext is a PostCSS plugin that helps you to use the latest CSS syntax today.
It transforms CSS specs into more compatible CSS so you don’t need to wait for browser support.

---

## Check out [cssnext website](http://cssnext.io/)

- [Features](http://cssnext.io/features/)
- [Setup](http://cssnext.io/setup/)
- [Usage](http://cssnext.io/usage/)
- [Playground](http://cssnext.io/playground/)
- [Migration to postcss-cssnext](http://cssnext.io/postcss/)

For questions and support please visit the
[support chat](https://gitter.im/MoOx/postcss-cssnext).

For offline documentation, check out `postcss-cssnext/docs/content`.

---

## CONTRIBUTING

* ⇄ Pull requests and ★ Stars are always welcome.
* For bugs and feature requests, please create an issue.
* Pull requests must be accompanied by passing automated tests (`$ npm test`).

## [Changelog](CHANGELOG.md)

## [License](LICENSE)

==> postcss-cssnext-3.1.1.tgz: package/README.md <==
# postcss-cssnext

[![Travis Build Status](https://img.shields.io/travis/MoOx/postcss-cssnext.svg?label=unix%20build)](https://travis-ci.org/MoOx/postcss-cssnext)
[![AppVeyor Build Status](https://img.shields.io/appveyor/ci/MoOx/postcss-cssnext.svg?label=windows%20build)](https://ci.appveyor.com/project/MoOx/postcss-cssnext)
[![Version](https://img.shields.io/npm/v/postcss-cssnext.svg)](https://github.com/MoOx/postcss-cssnext/blob/master/CHANGELOG.md)
[![Support on gitter chat](https://img.shields.io/badge/support-gitter%20chat-E40255.svg)](https://gitter.im/MoOx/postcss-cssnext)


> PostCSS plugin to use tomorrow’s CSS syntax, today.

PostCSS-cssnext is a PostCSS plugin that helps you to use the latest CSS syntax today.
It transforms CSS specs into more compatible CSS so you don’t need to wait for browser support.

---

## [Documentation](https://cssnext.github.io/)

- [Features](https://cssnext.github.io/features/)
- [Setup](https://cssnext.github.io/setup/)
- [Usage](https://cssnext.github.io/usage/)
- [Playground](https://cssnext.github.io/playground/)
- [Migration to postcss-cssnext](https://cssnext.github.io/postcss/)

For questions and support please visit the
[support chat](https://gitter.im/MoOx/postcss-cssnext).

For offline documentation, check out `postcss-cssnext/docs/content`.

---

## CONTRIBUTING

* ⇄ Pull requests and ★ Stars are always welcome.
* For bugs and feature requests, please create an issue.
* Pull requests must be accompanied by passing automated tests (`$ npm test`).

## [Changelog](CHANGELOG.md)

## [License](LICENSE)
